==> haskell-html-conduit-1.3.2-53-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.3.2
id: html-conduit-1.3.2-1UmJqmhTmiQJaBOfRangFj
key: html-conduit-1.3.2-1UmJqmhTmiQJaBOfRangFj
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.
category: Web, Text, Conduit
abi: 213e87731e60f24ea1f7fb573e3e1bac
exposed: True
exposed-modules:
    Text.HTML.DOM
hidden-modules: Text.HTML.TagStream
import-dirs: /usr/lib/ghc-8.6.5/site-local/html-conduit-1.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/html-conduit-1.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/html-conduit-1.3.2
hs-libraries: HShtml-conduit-1.3.2-1UmJqmhTmiQJaBOfRangFj
depends:
    attoparsec-0.13.2.2-4cHpHFFBuyN5UF0oDRVEML base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-JSdi7R8L6wUIGZiBi8qKpO
    conduit-extra-1.3.2-7VXB1JXOEmvJAFDjZlGCzm containers-0.6.0.1
    resourcet-1.2.2-BD7KiCA7p3Q4m6RD0qps5k text-1.2.3.1
    transformers-0.5.6.2 xml-conduit-1.8.0.1-5CVKDuq7Yn81PfLUhNE9t1
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.2-54-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.3.2
id: html-conduit-1.3.2-9uKjsjaAaAKKXqbf091zlz
key: html-conduit-1.3.2-9uKjsjaAaAKKXqbf091zlz
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.
category: Web, Text, Conduit
abi: 35eed1b4985997240b318780e7b1085a
exposed: True
exposed-modules:
    Text.HTML.DOM
hidden-modules: Text.HTML.TagStream
import-dirs: /usr/lib/ghc-8.6.5/site-local/html-conduit-1.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/html-conduit-1.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/html-conduit-1.3.2
hs-libraries: HShtml-conduit-1.3.2-9uKjsjaAaAKKXqbf091zlz
depends:
    attoparsec-0.13.2.2-4cHpHFFBuyN5UF0oDRVEML base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-BJf0jROjhGpHw40KA5fH20
    conduit-extra-1.3.2-2TNZEHQTl5oI3xQt2yRQt4 containers-0.6.0.1
    resourcet-1.2.2-BD7KiCA7p3Q4m6RD0qps5k text-1.2.3.1
    transformers-0.5.6.2 xml-conduit-1.8.0.1-DOQDrzOLddC5ApbbXE1AiD
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
